@@ -19,8 +19,8 @@
 #define DIFF_H
 
 #include <QPainter>
-#include <list>
-#include <vector>
+#include <QLinkedList>
+#include <QVector>
 #include <assert.h>
 #include "common.h"
 #include "fileaccess.h"
@@ -47,7 +47,8 @@ struct LineData
    const QChar* pFirstNonWhiteChar;
    int size;
 
-   LineData(){ pLine=0; pFirstNonWhiteChar=0; size=0; /*occurances=0;*/ bContainsPureComment=false; }
+   LineData(){ pLine=0; pFirstNonWhiteChar=0; size=0; /*occurances=0;*/ 
+               bContainsPureComment=false; }
    int width(int tabSize) const;  // Calcs width considering tabs.
    //int occurances;
    bool whiteLine() const { return pFirstNonWhiteChar-pLine == size; }
@@ -145,10 +146,10 @@ struct Diff3Line
 };
 
 
-class Diff3LineList : public std::list<Diff3Line>
+class Diff3LineList : public QLinkedList<Diff3Line>
 {
 };
-class Diff3LineVector : public std::vector<Diff3Line*>
+class Diff3LineVector : public QVector<Diff3Line*>
 {
 };
 
@@ -161,7 +162,7 @@ public:
    int wrapLineLength;
 };
 
-typedef std::vector<Diff3WrapLine> Diff3WrapLineVector;
+typedef QVector<Diff3WrapLine> Diff3WrapLineVector;
 
 
 class TotalDiffStatus
@@ -294,7 +295,7 @@ private:
       int m_size;
       int m_vSize; // Nr of lines in m_pBuf1 and size of m_v1, m_dv12 and m_dv13
       QString m_unicodeBuf;
-      std::vector<LineData> m_v;
+      QVector<LineData> m_v;
       bool m_bIsText;
       bool m_bIncompleteConversion;
       e_LineEndStyle m_eLineEndStyle;
