@@ -58,10 +58,10 @@ public:
    int getFirstLine();
    int calcTopLineInFile( int firstLine );
 
-   int getNofColumns();
+   int getMaxTextWidth();
    int getNofLines();
    int getNofVisibleLines();
-   int getNofVisibleColumns();
+   int getVisibleTextAreaWidth();
 
    int convertLineToDiff3LineIdx( int line );
    int convertDiff3LineIdxToLine( int d3lIdx );
@@ -76,11 +76,13 @@ public:
    void getSelectionRange( int* firstLine, int* lastLine, e_CoordType coordType );
 
    void setPaintingAllowed( bool bAllowPainting );
-   void recalcWordWrap( bool bWordWrap, int wrapLineVectorSize, int nofVisibleColumns );
+   void recalcWordWrap( bool bWordWrap, int wrapLineVectorSize, int nofVisibleColumns);
+   void recalcWordWrapHelper( int wrapLineVectorSize, int visibleTextWidth, int cacheListIdx);
    void print( MyPainter& painter, const QRect& r, int firstLine, int nofLinesPerPage );
 signals:
-   void resizeSignal( int nofVisibleColumns, int nofVisibleLines );
-   void scroll( int deltaX, int deltaY );
+   void resizeHeightChangedSignal(int nofVisibleLines);
+   void resizeWidthChangedSignal(int nofVisibleColumns);
+   void scroll(int deltaX, int deltaY);
    void newSelection();
    void selectionEnd();
    void setFastSelectorLine( int line );
@@ -89,7 +91,7 @@ signals:
 
 public slots:
    void setFirstLine( int line );
-   void setFirstColumn( int col );
+   void setHorizScrollOffset( int horizScrollOffset );
    void resetSelection();
    void setFastSelectorRange( int line1, int nofLines );
 
@@ -158,5 +160,7 @@ private:
    void insertCodec( const QString& visibleCodecName, QTextCodec* pCodec, QList<int> &CodecEnumList, QMenu* pMenu, int currentTextCodecEnum);
 };
 
+bool startRunnables();
+
 #endif
 
