@@ -64,7 +64,6 @@ static lin equivs_index;
 /* Number of elements allocated in the array `equivs'.  */
 static lin equivs_alloc;
 
-
 /* Check for binary files and compare them for exact identity.  */
 
 /* Return 1 if BUF contains a non text character.
@@ -166,7 +165,7 @@ void GnuDiff::find_and_hash_each_line (struct file_data *current)
 	switch (ignore_white_space)
 	  {
 	  case IGNORE_ALL_SPACE:
-	    while ( p<bufend && (c = *p) != '\n' )
+	    while ( p<bufend && !isEndOfLine(c = *p) )
             {
           if (! (isWhite(c) || (bIgnoreNumbers && (c.isDigit() || c=='-' || c=='.' )) ))
                   h = HASH (h, c.toLower().unicode());
@@ -175,7 +174,7 @@ void GnuDiff::find_and_hash_each_line (struct file_data *current)
 	    break;
 
 	  default:
-	    while ( p<bufend && (c = *p) != '\n' )
+	    while ( p<bufend && !isEndOfLine(c = *p) )
             {
                h = HASH (h, c.toLower().unicode());
                ++p;
@@ -186,16 +185,16 @@ void GnuDiff::find_and_hash_each_line (struct file_data *current)
 	switch (ignore_white_space)
 	  {
 	  case IGNORE_ALL_SPACE:
-	    while ( p<bufend && (c = *p) != '\n')
+	    while ( p<bufend && !isEndOfLine(c = *p) )
             {
-          if (! (isWhite(c)|| (bIgnoreNumbers && (c.isDigit() || c=='-' || c=='.' )) ))
+              if (! (isWhite(c)|| (bIgnoreNumbers && (c.isDigit() || c=='-' || c=='.' )) ))
                  h = HASH (h, c.unicode());
               ++p;
             }
 	    break;
 
 	  default:
-	    while ( p<bufend && (c = *p) != '\n')
+	    while ( p<bufend && !isEndOfLine(c = *p) )
             {
                h = HASH (h, c.unicode());
                ++p;
@@ -299,7 +298,7 @@ void GnuDiff::find_and_hash_each_line (struct file_data *current)
 
       line++;
 
-      while (p<bufend && *p++ != '\n')
+      while (p<bufend && !isEndOfLine(*p++) )
         continue;
     }
 
@@ -356,7 +355,7 @@ void GnuDiff::find_identical_ends (struct file_data filevec[])
   /* Now P0 and P1 point at the first nonmatching characters.  */
 
   /* Skip back to last line-beginning in the prefix. */
-  while (p0 != buffer0 && (p0[-1] != '\n' ))
+  while (p0 != buffer0 && ! isEndOfLine(p0[-1]) )
     p0--, p1--;
 
   /* Record the prefix.  */
@@ -393,7 +392,7 @@ void GnuDiff::find_identical_ends (struct file_data filevec[])
    {
       if (*p0 != *p1)
          ++p0;
-      while ( p0<pEnd0 && *p0++ != '\n')
+      while ( p0<pEnd0 && !isEndOfLine(*p0++) )
          continue;
    }
 
@@ -459,7 +458,7 @@ void GnuDiff::find_identical_ends (struct file_data filevec[])
               linbuf0 = (const QChar**) xrealloc (linbuf0, alloc_lines0 * sizeof(*linbuf0));
 	    }
 	  linbuf0[l] = p0;
-	  while ( p0<pEnd0 && *p0++ != '\n' )
+	  while ( p0<pEnd0 && !isEndOfLine(*p0++) )
 	    continue;
 	}
     }
