@@ -84,7 +84,7 @@ static void showHelp()
 
 #ifndef Q_OS_OS2
       char buf[256];
-      HINSTANCE hi = FindExecutableA( helpFile.fileName().toAscii(), helpFile.absolutePath().toAscii(), buf );
+      HINSTANCE hi = FindExecutableA( helpFile.fileName().toLatin1(), helpFile.absolutePath().toLatin1(), buf );
       if ( (quintptr)hi<=32 )
       {
 #endif
@@ -119,9 +119,13 @@ static void showHelp()
 QString getTranslationDir(const QString& locale)
 {
    #if defined(_WIN32) || defined(Q_OS_OS2)
+      (void) locale; 
       QString exePath;
       exePath = QCoreApplication::applicationDirPath();
       return exePath+"/translations";
+   #elif defined(__APPLE__)
+      QString exePath = QCoreApplication::applicationDirPath();
+      return exePath+"/../Resources/translations";
    #else
       return  (QString)"/usr/share/locale/" + locale + "/LC_MESSAGES";
    #endif
@@ -766,9 +770,11 @@ KFontChooser::KFontChooser( QWidget* pParent )
    m_pLabel = new QLabel( "", this );
    m_pLabel->setFont( m_font );
    m_pLabel->setMinimumWidth(200);
-   m_pLabel->setText( "The quick brown fox jumps over the river\n"
+   QChar visualTab(0x2192);
+   QChar visualSpace((ushort)0xb7);
+   m_pLabel->setText( QString("The quick brown fox jumps over the river\n"
                       "but the little red hen escapes with a shiver.\n"
-                      ":-)");
+                      ":-)")+visualTab+visualSpace);
    pLayout->addWidget(m_pLabel);
 }
 
@@ -786,29 +792,9 @@ void KFontChooser::setFont( const QFont& font, bool )
 
 void KFontChooser::slotSelectFont()
 {
-   for(;;)
-   {
-      bool bOk;
-      m_font = QFontDialog::getFont(&bOk, m_font );
-      m_pLabel->setFont( m_font );   
-      QFontMetrics fm(m_font);
-
-      // Variable width font.
-      if ( fm.width('W')!=fm.width('i') )
-      {
-         int result = KMessageBox::warningYesNo(m_pParent, i18n(
-            "You selected a variable width font.\n\n"
-            "Because this program doesn't handle variable width fonts\n"
-            "correctly, you might experience problems while editing.\n\n"
-            "Do you want to continue or do you want to select another font."),
-            i18n("Incompatible font."),
-            i18n("Continue at my own risk"), i18n("Select another font"));
-         if (result==KMessageBox::Yes)
-            return;
-      }
-      else
-         return;
-   }
+   bool bOk;
+   m_font = QFontDialog::getFont(&bOk, m_font );
+   m_pLabel->setFont( m_font );
 }
 
 
@@ -1030,10 +1016,16 @@ bool KCmdLineArgs::isSet(const QString& s)
 KApplication* kapp;
 
 KApplication::KApplication()
-: QApplication( s_argc,s_argv )
+: QApplication(s_argc, s_argv)
 {
    kapp = this;
+   #if ! ( defined(_WIN32) || defined(Q_OS_OS2) )
+   parseOptions();
+   #endif
+}
 
+void KApplication::parseOptions()
+{
    //setStyle( new QWindowsStyle ); // doesn't show checkmarks on checkable icons in menu
 
    int nofOptions=0;
@@ -1225,9 +1217,9 @@ QObject* KLibFactory::create(QObject* pParent, const QString& name, const QStrin
 {
    KParts::Factory* f = qobject_cast<KParts::Factory*>(this);
    if (f!=0)
-      return f->createPartObject( (QWidget*)pParent, name.toAscii(),
-                                            pParent, name.toAscii(),
-                                            classname.toAscii(),  QStringList() );
+      return f->createPartObject( (QWidget*)pParent, name.toLatin1(),
+                                            pParent, name.toLatin1(),
+                                            classname.toLatin1(),  QStringList() );
    else
       return 0;
 }
