@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
+#include "stable.h"
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 #include <klocale.h>
@@ -28,6 +28,7 @@
 #include <QLocale>
 #include <QFont>
 #include <QClipboard>
+#include <QMainWindow>
 #include <vector>
 
 #ifdef KREPLACEMENTS_H
@@ -167,7 +168,7 @@ int main(int argc, char *argv[])
    else if ( sizeof(void*)==4 )
        appVersion += " (32 bit)";
    const KLocalizedString description = ki18n("Tool for Comparison and Merge of Files and Directories");
-   const KLocalizedString copyright = ki18n("(c) 2002-2012 Joachim Eibl");
+   const KLocalizedString copyright = ki18n("(c) 2002-2014 Joachim Eibl");
    const QByteArray& homePage = "http://kdiff3.sourceforge.net/";
    const QByteArray& bugsAddress = "joachim.eibl" "@" "gmx.de";
    KAboutData aboutData( appName, appCatalog, i18nName, 
@@ -219,11 +220,18 @@ int main(int argc, char *argv[])
    options.add( "+[File2]", ki18n("file2 to open") );
    options.add( "+[File3]", ki18n("file3 to open") );
 
-   initialiseCmdLineArgs( options );
-
-   KCmdLineArgs::addCmdLineOptions( options );
-
+#if defined(_WIN32) || defined(Q_OS_OS2)
+   // on Windows applicationDirPath() is called and needs a QApplication
    KApplication app;
+   initialiseCmdLineArgs( options );
+   KCmdLineArgs::addCmdLineOptions( options );
+   app.parseOptions();
+#else
+   // on other systems options should be initialized before creating the QApplication 
+   initialiseCmdLineArgs( options );
+   KCmdLineArgs::addCmdLineOptions( options );
+   KApplication app;
+#endif
 
 #ifdef KREPLACEMENTS_H
    QString locale;
