@@ -199,8 +199,8 @@ public:
       *m_pVar = defaultVal;
       m_defaultVal = defaultVal;
    }
-   void setToDefault(){ setFont( m_defaultVal, true /*only fixed*/ ); }
-   void setToCurrent(){ setFont( *m_pVar, true /*only fixed*/ ); }
+   void setToDefault(){ setFont( m_defaultVal, false ); }
+   void setToCurrent(){ setFont( *m_pVar, false ); }
    void apply()       { *m_pVar = font();}
    void write(ValueMap* config){ config->writeEntry(m_saveName, *m_pVar );   }
    void read (ValueMap* config){ *m_pVar = config->readFontEntry( m_saveName, m_pVar ); }
@@ -375,7 +375,7 @@ private:
 
 class OptionEncodingComboBox : public QComboBox, public OptionItem
 {
-   std::vector<QTextCodec*> m_codecVec;
+   QVector<QTextCodec*> m_codecVec;
    QTextCodec** m_ppVarCodec;
 public:
    OptionEncodingComboBox( const QString& saveName, QTextCodec** ppVarCodec,
@@ -411,7 +411,7 @@ public:
    {
       if (c!=0)
       {
-         for( unsigned int i=0; i<m_codecVec.size(); ++i )
+         for( int i=0; i<m_codecVec.size(); ++i )
          {
             if ( c==m_codecVec[i] )
                return;  // don't insert any codec twice
@@ -441,7 +441,7 @@ public:
    {
       if (m_ppVarCodec!=0)
       {
-         for(unsigned int i=0; i<m_codecVec.size(); ++i)
+         for( int i=0; i<m_codecVec.size(); ++i)
          {
             if ( *m_ppVarCodec==m_codecVec[i] )
             {
@@ -462,7 +462,7 @@ public:
    void read (ValueMap* config)
    {
       QString codecName = config->readEntry( m_saveName, QString(m_codecVec[ currentIndex() ]->name()) );
-      for(unsigned int i=0; i<m_codecVec.size(); ++i)
+      for( int i=0; i<m_codecVec.size(); ++i)
       {
          if ( codecName == m_codecVec[i]->name() )
          {
@@ -824,13 +824,15 @@ void OptionDialog::setupDiffPage( void )
    QLabel* label=0;
 
    m_options.m_bPreserveCarriageReturn = false;
-   //OptionCheckBox* pPreserveCarriageReturn = new OptionCheckBox( i18n("Preserve carriage return"), false, "PreserveCarriageReturn", &m_bPreserveCarriageReturn, page, this );
-   //gbox->addWidget( pPreserveCarriageReturn, line, 0, 1, 2 );
-   //pPreserveCarriageReturn->setToolTip( i18n(
-   //   "Show carriage return characters '\\r' if they exist.\n"
-   //   "Helps to compare files that were modified under different operating systems.")
-   //   );
-   //++line;
+/*
+   OptionCheckBox* pPreserveCarriageReturn = new OptionCheckBox( i18n("Preserve carriage return"), false, "PreserveCarriageReturn", &m_options.m_bPreserveCarriageReturn, page, this );
+   gbox->addWidget( pPreserveCarriageReturn, line, 0, 1, 2 );
+   pPreserveCarriageReturn->setToolTip( i18n(
+      "Show carriage return characters '\\r' if they exist.\n"
+      "Helps to compare files that were modified under different operating systems.")
+      );
+   ++line;
+*/
    QString treatAsWhiteSpace = " ("+i18n("Treat as white space.")+")";
 
    OptionCheckBox* pIgnoreNumbers = new OptionCheckBox( i18n("Ignore numbers")+treatAsWhiteSpace, false, "IgnoreNumbers", &m_options.m_bIgnoreNumbers, page, this );
@@ -1450,7 +1452,7 @@ static const char* countryMap[]={
    pLanguage->addItem( "Auto" );  // Must not translate, won't work otherwise!
    pLanguage->addItem( "en_orig" );
       
-#if !defined(_WIN32) && !defined(Q_OS_OS2) 
+#if !defined(_WIN32) && !defined(Q_OS_OS2) && !defined(__APPLE__)
    // Read directory: Find all kdiff3_*.qm-files and insert the found files here
    QDir localeDir( "/usr/share/locale" ); // See also kreplacements.cpp: getTranslationDir()
    QStringList dirList = localeDir.entryList(QDir::Dirs | QDir::NoDotAndDotDot, QDir::Name);
@@ -1711,23 +1713,6 @@ void OptionDialog::slotOk( void )
 {
    slotApply();
 
-   // My system returns variable width fonts even though I
-   // disabled this. Even QFont::fixedPitch() doesn't work.
-   QFontMetrics fm(m_options.m_font);
-   if ( fm.width('W')!=fm.width('i') )
-   {
-      int result = KMessageBox::warningYesNo(this, i18n(
-         "You selected a variable width font.\n\n"
-         "Because this program doesn't handle variable width fonts\n"
-         "correctly, you might experience problems while editing.\n\n"
-         "Do you want to continue or do you want to select another font."),
-         i18n("Incompatible Font"),
-         KGuiItem( i18n("Continue at Own Risk") ),
-         KGuiItem( i18n("Select Another Font")) );
-      if (result==KMessageBox::No)
-         return;
-   }
-
    accept();
 }
 
