@@ -2,6 +2,9 @@
 #define STABLE_H
 #include <QtCore>
 #include <QtGui>
+#if QT_VERSION>=0x050000
+#include <QtWidgets/QtWidgets>
+#endif
 #ifdef _WIN32
 #include <qt_windows.h>
 #endif
